local AddonName, namespace = ...;

-- validity is set by InlinePower.lua, if invalid, its true
if( namespace.invalid ) then return end

-- our POWER "class", every single instance represents a power indicator which can be activated or deactivated
local POWER = {};

local UpdateTime = 0.033;
local AlphaChange = 0.15;
local AlphaDefault = 0.2;

-- Activating smooth
local function activate_OnUpdate(self, elapsed)
	self.elapsed = self.elapsed + elapsed;
	
	if( self.elapsed >= UpdateTime ) then
		self.elapsed = 0;
		
		self:SetAlpha(self:GetAlpha() + AlphaChange);
		if( self:GetAlpha() >= 1 ) then
			self:SetScript("OnUpdate", nil);
		end
	end
end

-- Deactivating smooth
local function deactivate_OnUpdate(self, elapsed)
	self.elapsed = self.elapsed + elapsed;
	
	if( self.elapsed >= UpdateTime ) then
		self.elapsed = 0;
		
		self:SetAlpha(self:GetAlpha() - AlphaChange);
		if( self:GetAlpha() <= AlphaDefault ) then
			self:SetAlpha(AlphaDefault);
			self:SetScript("OnUpdate", nil);
		end
	end
end

-- Gets called from PitBull4's frame updater
function POWER:Activate()
	self.active = true;
	
	self:SetScript("OnUpdate", activate_OnUpdate);
	
	local color = self.color;
	self.tex:SetTexture(color.r, color.g, color.b, 1);
end

-- Gets called from PitBull4's frame updater
function POWER:Deactivate()
	self.active = nil;
	
	self:SetScript("OnUpdate", deactivate_OnUpdate);
	
	local color = self.color;
	self.tex:SetTexture(color.r, color.g, color.b, 1);
end

function POWER:UpdateColor(color)
	self.color = color;
end

-- Our POWER "class" is a new control type called InlinePower
PitBull4.Controls.MakeNewControlType("InlinePower", "Button", function(control)
	-- on create
	for k, v in pairs(POWER) do
		control[k] = v;
	end
	
	-- need to convert to PitBull4 texture later
	local t = control:CreateTexture(nil, "ARTWORK");
	t:SetAllPoints(control);
	t:Show();
	control.tex = t;
	
	control.elapsed = 0;
	control:SetAlpha(AlphaDefault);
	
end, function(control, id)
	-- on retrieve
	control.id = id;
	
end, function(control)
	-- on delete
	control.id = nil;
	control.active = nil;
	control.elapsed = nil;
end)
